import type { BatchRequest } from '../models/BatchRequest';
import type { BatchResponse } from '../models/BatchResponse';
import type { CancelablePromise } from '../core/CancelablePromise';
import type { BaseHttpRequest } from '../core/BaseHttpRequest';
export declare class BatchApiService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Submit parallel requests
     * Make multiple requests in parallel to Asana's API.
     * @returns any Successfully completed the requested batch API operations.
     * @throws ApiError
     */
    createBatchRequest({ requestBody, optPretty, optFields, }: {
        /**
         * The requests to batch together via the Batch API.
         */
        requestBody: {
            data?: BatchRequest;
        };
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: Array<BatchResponse>;
    }>;
}
