"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventsService = void 0;
class EventsService {
    constructor(httpRequest) {
        this.httpRequest = httpRequest;
    }
    /**
     * Get events on a resource
     * Returns the full record for all events that have occurred since the sync
     * token was created.
     *
     * A `GET` request to the endpoint `/[path_to_resource]/events` can be made in
     * lieu of including the resource ID in the data for the request.
     *
     * Asana limits a single sync token to 100 events. If more than 100 events exist
     * for a given resource, `has_more: true` will be returned in the response, indicating
     * that there are more events to pull.
     *
     * *Note: The resource returned will be the resource that triggered the
     * event. This may be different from the one that the events were requested
     * for. For example, a subscription to a project will contain events for
     * tasks contained within the project.*
     * @returns any Successfully retrieved events.
     * @throws ApiError
     */
    getEvents({ resource, sync, optPretty, optFields, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/events',
            query: {
                'resource': resource,
                'sync': sync,
                'opt_pretty': optPretty,
                'opt_fields': optFields,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
}
exports.EventsService = EventsService;
