"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GoalRelationshipsService = void 0;
class GoalRelationshipsService {
    constructor(httpRequest) {
        this.httpRequest = httpRequest;
    }
    /**
     * Get a goal relationship
     * Returns the complete updated goal relationship record for a single goal relationship.
     * @returns any Successfully retrieved the record for the goal relationship.
     * @throws ApiError
     */
    getGoalRelationship({ goalRelationshipGid, optPretty, optFields, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/goal_relationships/{goal_relationship_gid}',
            path: {
                'goal_relationship_gid': goalRelationshipGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Update a goal relationship
     * An existing goal relationship can be updated by making a PUT request on the URL for
     * that goal relationship. Only the fields provided in the `data` block will be updated;
     * any unspecified fields will remain unchanged.
     *
     * Returns the complete updated goal relationship record.
     * @returns any Successfully updated the goal relationship.
     * @throws ApiError
     */
    updateGoalRelationship({ goalRelationshipGid, requestBody, optPretty, optFields, }) {
        return this.httpRequest.request({
            method: 'PUT',
            url: '/goal_relationships/{goal_relationship_gid}',
            path: {
                'goal_relationship_gid': goalRelationshipGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
            },
            body: requestBody,
            mediaType: 'application/json',
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Get goal relationships
     * Returns compact goal relationship records.
     * @returns any Successfully retrieved the requested goal relationships.
     * @throws ApiError
     */
    getGoalRelationships({ supportedGoal, optPretty, optFields, resourceSubtype, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/goal_relationships',
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
                'supported_goal': supportedGoal,
                'resource_subtype': resourceSubtype,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Add a supporting goal relationship
     * Creates a goal relationship by adding a supporting resource to a given goal.
     *
     * Returns the newly created goal relationship record.
     * @returns any Successfully created the goal relationship.
     * @throws ApiError
     */
    addSupportingRelationship({ goalGid, requestBody, optPretty, optFields, }) {
        return this.httpRequest.request({
            method: 'POST',
            url: '/goals/{goal_gid}/addSupportingRelationship',
            path: {
                'goal_gid': goalGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
            },
            body: requestBody,
            mediaType: 'application/json',
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Removes a supporting goal relationship
     * Removes a goal relationship for a given parent goal.
     * @returns any Successfully removed the goal relationship.
     * @throws ApiError
     */
    removeSupportingRelationship({ goalGid, requestBody, optPretty, optFields, }) {
        return this.httpRequest.request({
            method: 'POST',
            url: '/goals/{goal_gid}/removeSupportingRelationship',
            path: {
                'goal_gid': goalGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
            },
            body: requestBody,
            mediaType: 'application/json',
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
}
exports.GoalRelationshipsService = GoalRelationshipsService;
