import type { OrganizationExportCompact } from '../models/OrganizationExportCompact';
import type { OrganizationExportRequest } from '../models/OrganizationExportRequest';
import type { CancelablePromise } from '../core/CancelablePromise';
import type { BaseHttpRequest } from '../core/BaseHttpRequest';
export declare class OrganizationExportsService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Create an organization export request
     * This method creates a request to export an Organization. Asana will complete the export at some point after you create the request.
     * @returns any Successfully created organization export request.
     * @throws ApiError
     */
    createOrganizationExport({ requestBody, optPretty, optFields, limit, offset, }: {
        /**
         * The organization to export.
         */
        requestBody: {
            data?: OrganizationExportRequest;
        };
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
        /**
         * Results per page.
         * The number of objects to return per page. The value must be between 1 and 100.
         */
        limit?: number;
        /**
         * Offset token.
         * An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results.
         * 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
         */
        offset?: string;
    }): CancelablePromise<{
        data?: OrganizationExportCompact;
    }>;
    /**
     * Get details on an org export request
     * Returns details of a previously-requested Organization export.
     * @returns any Successfully retrieved organization export object.
     * @throws ApiError
     */
    getOrganizationExport({ organizationExportGid, optPretty, optFields, }: {
        /**
         * Globally unique identifier for the organization export.
         */
        organizationExportGid: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: OrganizationExportCompact;
    }>;
}
