import type { PortfolioMembershipCompact } from '../models/PortfolioMembershipCompact';
import type { CancelablePromise } from '../core/CancelablePromise';
import type { BaseHttpRequest } from '../core/BaseHttpRequest';
export declare class PortfolioMembershipsService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get multiple portfolio memberships
     * Returns a list of portfolio memberships in compact representation. You must specify `portfolio`, `portfolio` and `user`, or `workspace` and `user`.
     * @returns any Successfully retrieved portfolio memberships.
     * @throws ApiError
     */
    getPortfolioMemberships({ portfolio, workspace, user, optPretty, optFields, limit, offset, }: {
        /**
         * The portfolio to filter results on.
         */
        portfolio?: string;
        /**
         * The workspace to filter results on.
         */
        workspace?: string;
        /**
         * A string identifying a user. This can either be the string "me", an email, or the gid of a user.
         */
        user?: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
        /**
         * Results per page.
         * The number of objects to return per page. The value must be between 1 and 100.
         */
        limit?: number;
        /**
         * Offset token.
         * An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results.
         * 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
         */
        offset?: string;
    }): CancelablePromise<{
        data?: Array<PortfolioMembershipCompact>;
    }>;
    /**
     * Get a portfolio membership
     * Returns the complete portfolio record for a single portfolio membership.
     * @returns any Successfully retrieved the requested portfolio membership.
     * @throws ApiError
     */
    getPortfolioMembership({ portfolioMembershipGid, optPretty, optFields, }: {
        portfolioMembershipGid: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: PortfolioMembershipCompact;
    }>;
    /**
     * Get memberships from a portfolio
     * Returns the compact portfolio membership records for the portfolio.
     * @returns any Successfully retrieved the requested portfolio's memberships.
     * @throws ApiError
     */
    getPortfolioMembershipsForPortfolio({ portfolioGid, user, optPretty, optFields, limit, offset, }: {
        /**
         * Globally unique identifier for the portfolio.
         */
        portfolioGid: string;
        /**
         * A string identifying a user. This can either be the string "me", an email, or the gid of a user.
         */
        user?: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
        /**
         * Results per page.
         * The number of objects to return per page. The value must be between 1 and 100.
         */
        limit?: number;
        /**
         * Offset token.
         * An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results.
         * 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
         */
        offset?: string;
    }): CancelablePromise<{
        data?: Array<PortfolioMembershipCompact>;
    }>;
}
