import type { EmptyResponse } from '../models/EmptyResponse';
import type { ProjectBriefRequest } from '../models/ProjectBriefRequest';
import type { ProjectBriefResponse } from '../models/ProjectBriefResponse';
import type { CancelablePromise } from '../core/CancelablePromise';
import type { BaseHttpRequest } from '../core/BaseHttpRequest';
export declare class ProjectBriefsService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get a project brief
     * Get the full record for a project brief.
     * @returns any Successfully retrieved the record for a project brief.
     * @throws ApiError
     */
    getProjectBrief({ projectBriefGid, optPretty, optFields, }: {
        /**
         * Globally unique identifier for the project brief.
         */
        projectBriefGid: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: ProjectBriefResponse;
    }>;
    /**
     * Update a project brief
     * An existing project brief can be updated by making a PUT request on the URL for
     * that project brief. Only the fields provided in the `data` block will be updated;
     * any unspecified fields will remain unchanged.
     *
     * Returns the complete updated project brief record.
     * @returns any Successfully updated the project brief.
     * @throws ApiError
     */
    updateProjectBrief({ projectBriefGid, requestBody, optPretty, optFields, }: {
        /**
         * Globally unique identifier for the project brief.
         */
        projectBriefGid: string;
        /**
         * The updated fields for the project brief.
         */
        requestBody: {
            data?: ProjectBriefRequest;
        };
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: ProjectBriefResponse;
    }>;
    /**
     * Delete a project brief
     * Deletes a specific, existing project brief.
     *
     * Returns an empty data record.
     * @returns any Successfully deleted the specified project brief.
     * @throws ApiError
     */
    deleteProjectBrief({ projectBriefGid, optPretty, optFields, }: {
        /**
         * Globally unique identifier for the project brief.
         */
        projectBriefGid: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: EmptyResponse;
    }>;
    /**
     * Create a project brief
     * Creates a new project brief.
     *
     * Returns the full record of the newly created project brief.
     * @returns any Successfully created a new project brief.
     * @throws ApiError
     */
    createProjectBrief({ projectGid, requestBody, optPretty, optFields, }: {
        /**
         * Globally unique identifier for the project.
         */
        projectGid: string;
        /**
         * The project brief to create.
         */
        requestBody: {
            data?: ProjectBriefRequest;
        };
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: ProjectBriefResponse;
    }>;
}
