"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProjectMembershipsService = void 0;
class ProjectMembershipsService {
    constructor(httpRequest) {
        this.httpRequest = httpRequest;
    }
    /**
     * Get a project membership
     * Returns the complete project record for a single project membership.
     * @returns any Successfully retrieved the requested project membership.
     * @throws ApiError
     */
    getProjectMembership({ projectMembershipGid, optPretty, optFields, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/project_memberships/{project_membership_gid}',
            path: {
                'project_membership_gid': projectMembershipGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Get memberships from a project
     * Returns the compact project membership records for the project.
     * @returns any Successfully retrieved the requested project's memberships.
     * @throws ApiError
     */
    getProjectMembershipsForProject({ projectGid, user, optPretty, optFields, limit, offset, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/projects/{project_gid}/project_memberships',
            path: {
                'project_gid': projectGid,
            },
            query: {
                'user': user,
                'opt_pretty': optPretty,
                'opt_fields': optFields,
                'limit': limit,
                'offset': offset,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
}
exports.ProjectMembershipsService = ProjectMembershipsService;
