import type { EmptyResponse } from '../models/EmptyResponse';
import type { ProjectStatusBase } from '../models/ProjectStatusBase';
import type { ProjectStatusCompact } from '../models/ProjectStatusCompact';
import type { ProjectStatusResponse } from '../models/ProjectStatusResponse';
import type { CancelablePromise } from '../core/CancelablePromise';
import type { BaseHttpRequest } from '../core/BaseHttpRequest';
export declare class ProjectStatusesService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get a project status
     * *Deprecated: new integrations should prefer the `/status_updates/{status_gid}` route.*
     *
     * Returns the complete record for a single status update.
     * @returns any Successfully retrieved the specified project's status updates.
     * @throws ApiError
     */
    getProjectStatus({ projectStatusGid, optPretty, optFields, }: {
        /**
         * The project status update to get.
         */
        projectStatusGid: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: ProjectStatusResponse;
    }>;
    /**
     * Delete a project status
     * *Deprecated: new integrations should prefer the `/status_updates/{status_gid}` route.*
     *
     * Deletes a specific, existing project status update.
     *
     * Returns an empty data record.
     * @returns any Successfully deleted the specified project status.
     * @throws ApiError
     */
    deleteProjectStatus({ projectStatusGid, optPretty, optFields, }: {
        /**
         * The project status update to get.
         */
        projectStatusGid: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: EmptyResponse;
    }>;
    /**
     * Get statuses from a project
     * *Deprecated: new integrations should prefer the `/status_updates` route.*
     *
     * Returns the compact project status update records for all updates on the project.
     * @returns any Successfully retrieved the specified project's status updates.
     * @throws ApiError
     */
    getProjectStatusesForProject({ projectGid, optPretty, optFields, limit, offset, }: {
        /**
         * Globally unique identifier for the project.
         */
        projectGid: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
        /**
         * Results per page.
         * The number of objects to return per page. The value must be between 1 and 100.
         */
        limit?: number;
        /**
         * Offset token.
         * An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results.
         * 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
         */
        offset?: string;
    }): CancelablePromise<{
        data?: Array<ProjectStatusCompact>;
    }>;
    /**
     * Create a project status
     * *Deprecated: new integrations should prefer the `/status_updates` route.*
     *
     * Creates a new status update on the project.
     *
     * Returns the full record of the newly created project status update.
     * @returns any Successfully created a new story.
     * @throws ApiError
     */
    createProjectStatusForProject({ projectGid, requestBody, optPretty, optFields, }: {
        /**
         * Globally unique identifier for the project.
         */
        projectGid: string;
        /**
         * The project status to create.
         */
        requestBody: {
            data?: ProjectStatusBase;
        };
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: ProjectStatusResponse;
    }>;
}
