"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProjectStatusesService = void 0;
class ProjectStatusesService {
    constructor(httpRequest) {
        this.httpRequest = httpRequest;
    }
    /**
     * Get a project status
     * *Deprecated: new integrations should prefer the `/status_updates/{status_gid}` route.*
     *
     * Returns the complete record for a single status update.
     * @returns any Successfully retrieved the specified project's status updates.
     * @throws ApiError
     */
    getProjectStatus({ projectStatusGid, optPretty, optFields, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/project_statuses/{project_status_gid}',
            path: {
                'project_status_gid': projectStatusGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Delete a project status
     * *Deprecated: new integrations should prefer the `/status_updates/{status_gid}` route.*
     *
     * Deletes a specific, existing project status update.
     *
     * Returns an empty data record.
     * @returns any Successfully deleted the specified project status.
     * @throws ApiError
     */
    deleteProjectStatus({ projectStatusGid, optPretty, optFields, }) {
        return this.httpRequest.request({
            method: 'DELETE',
            url: '/project_statuses/{project_status_gid}',
            path: {
                'project_status_gid': projectStatusGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Get statuses from a project
     * *Deprecated: new integrations should prefer the `/status_updates` route.*
     *
     * Returns the compact project status update records for all updates on the project.
     * @returns any Successfully retrieved the specified project's status updates.
     * @throws ApiError
     */
    getProjectStatusesForProject({ projectGid, optPretty, optFields, limit, offset, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/projects/{project_gid}/project_statuses',
            path: {
                'project_gid': projectGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
                'limit': limit,
                'offset': offset,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Create a project status
     * *Deprecated: new integrations should prefer the `/status_updates` route.*
     *
     * Creates a new status update on the project.
     *
     * Returns the full record of the newly created project status update.
     * @returns any Successfully created a new story.
     * @throws ApiError
     */
    createProjectStatusForProject({ projectGid, requestBody, optPretty, optFields, }) {
        return this.httpRequest.request({
            method: 'POST',
            url: '/projects/{project_gid}/project_statuses',
            path: {
                'project_gid': projectGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
            },
            body: requestBody,
            mediaType: 'application/json',
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
}
exports.ProjectStatusesService = ProjectStatusesService;
