"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProjectTemplatesService = void 0;
class ProjectTemplatesService {
    constructor(httpRequest) {
        this.httpRequest = httpRequest;
    }
    /**
     * Get a project template
     * Returns the complete project template record for a single project template.
     * @returns any Successfully retrieved the requested project template.
     * @throws ApiError
     */
    getProjectTemplate({ projectTemplateGid, optPretty, optFields, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/project_templates/{project_template_gid}',
            path: {
                'project_template_gid': projectTemplateGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Get multiple project templates
     * Returns the compact project template records for all project templates in the given team or workspace.
     * @returns any Successfully retrieved the requested team's or workspace's project templates.
     * @throws ApiError
     */
    getProjectTemplates({ optPretty, optFields, workspace, team, limit, offset, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/project_templates',
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
                'workspace': workspace,
                'team': team,
                'limit': limit,
                'offset': offset,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Get a team's project templates
     * Returns the compact project template records for all project templates in the team.
     * @returns any Successfully retrieved the requested team's project templates.
     * @throws ApiError
     */
    getProjectTemplatesForTeam({ teamGid, optPretty, optFields, limit, offset, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/teams/{team_gid}/project_templates',
            path: {
                'team_gid': teamGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
                'limit': limit,
                'offset': offset,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Instantiate a project from a project template
     * Creates and returns a job that will asynchronously handle the project instantiation.
     *
     * To form this request, it is recommended to first make a request to [get a project template](/docs/get-a-project-template). Then, from the response, copy the `gid` from the object in the `requested_dates` array. This `gid` should be used in `requested_dates` to instantiate a project.
     *
     * _Note: The body of this request will differ if your workspace is an organization. To determine if your workspace is an organization, use the [is_organization](/docs/workspace) parameter._
     * @returns any Successfully created the job to handle project instantiation.
     * @throws ApiError
     */
    instantiateProject({ projectTemplateGid, optPretty, optFields, requestBody, }) {
        return this.httpRequest.request({
            method: 'POST',
            url: '/project_templates/{project_template_gid}/instantiateProject',
            path: {
                'project_template_gid': projectTemplateGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
            },
            body: requestBody,
            mediaType: 'application/json',
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
}
exports.ProjectTemplatesService = ProjectTemplatesService;
