"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StatusUpdatesService = void 0;
class StatusUpdatesService {
    constructor(httpRequest) {
        this.httpRequest = httpRequest;
    }
    /**
     * Get a status update
     * Returns the complete record for a single status update.
     * @returns any Successfully retrieved the specified object's status updates.
     * @throws ApiError
     */
    getStatus({ statusGid, optPretty, optFields, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/status_updates/{status_gid}',
            path: {
                'status_gid': statusGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Delete a status update
     * Deletes a specific, existing status update.
     *
     * Returns an empty data record.
     * @returns any Successfully deleted the specified status.
     * @throws ApiError
     */
    deleteStatus({ statusGid, optPretty, optFields, }) {
        return this.httpRequest.request({
            method: 'DELETE',
            url: '/status_updates/{status_gid}',
            path: {
                'status_gid': statusGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Get status updates from an object
     * Returns the compact status update records for all updates on the object.
     * @returns any Successfully retrieved the specified object's status updates.
     * @throws ApiError
     */
    getStatusesForObject({ parent, optPretty, optFields, limit, offset, createdSince, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/status_updates',
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
                'limit': limit,
                'offset': offset,
                'parent': parent,
                'created_since': createdSince,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Create a status update
     * Creates a new status update on an object.
     * Returns the full record of the newly created status update.
     * @returns any Successfully created a new status update.
     * @throws ApiError
     */
    createStatusForObject({ requestBody, optPretty, optFields, limit, offset, }) {
        return this.httpRequest.request({
            method: 'POST',
            url: '/status_updates',
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
                'limit': limit,
                'offset': offset,
            },
            body: requestBody,
            mediaType: 'application/json',
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
}
exports.StatusUpdatesService = StatusUpdatesService;
