import type { TeamMembershipCompact } from '../models/TeamMembershipCompact';
import type { CancelablePromise } from '../core/CancelablePromise';
import type { BaseHttpRequest } from '../core/BaseHttpRequest';
export declare class TeamMembershipsService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get a team membership
     * Returns the complete team membership record for a single team membership.
     * @returns any Successfully retrieved the requested team membership.
     * @throws ApiError
     */
    getTeamMembership({ teamMembershipGid, optPretty, optFields, }: {
        teamMembershipGid: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: TeamMembershipCompact;
    }>;
    /**
     * Get team memberships
     * Returns compact team membership records.
     * @returns any Successfully retrieved the requested team memberships.
     * @throws ApiError
     */
    getTeamMemberships({ optPretty, optFields, limit, offset, team, user, workspace, }: {
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
        /**
         * Results per page.
         * The number of objects to return per page. The value must be between 1 and 100.
         */
        limit?: number;
        /**
         * Offset token.
         * An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results.
         * 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
         */
        offset?: string;
        /**
         * Globally unique identifier for the team.
         */
        team?: string;
        /**
         * A string identifying a user. This can either be the string "me", an email, or the gid of a user. This parameter must be used with the workspace parameter.
         */
        user?: string;
        /**
         * Globally unique identifier for the workspace. This parameter must be used with the user parameter.
         */
        workspace?: string;
    }): CancelablePromise<{
        data?: Array<TeamMembershipCompact>;
    }>;
    /**
     * Get memberships from a team
     * Returns the compact team memberships for the team.
     * @returns any Successfully retrieved the requested team's memberships.
     * @throws ApiError
     */
    getTeamMembershipsForTeam({ teamGid, optPretty, optFields, limit, offset, }: {
        /**
         * Globally unique identifier for the team.
         */
        teamGid: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
        /**
         * Results per page.
         * The number of objects to return per page. The value must be between 1 and 100.
         */
        limit?: number;
        /**
         * Offset token.
         * An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results.
         * 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
         */
        offset?: string;
    }): CancelablePromise<{
        data?: Array<TeamMembershipCompact>;
    }>;
    /**
     * Get memberships from a user
     * Returns the compact team membership records for the user.
     * @returns any Successfully retrieved the requested users's memberships.
     * @throws ApiError
     */
    getTeamMembershipsForUser({ userGid, workspace, optPretty, optFields, limit, offset, }: {
        /**
         * A string identifying a user. This can either be the string "me", an email, or the gid of a user.
         */
        userGid: string;
        /**
         * Globally unique identifier for the workspace.
         */
        workspace: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
        /**
         * Results per page.
         * The number of objects to return per page. The value must be between 1 and 100.
         */
        limit?: number;
        /**
         * Offset token.
         * An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results.
         * 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
         */
        offset?: string;
    }): CancelablePromise<{
        data?: Array<TeamMembershipCompact>;
    }>;
}
