"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TeamMembershipsService = void 0;
class TeamMembershipsService {
    constructor(httpRequest) {
        this.httpRequest = httpRequest;
    }
    /**
     * Get a team membership
     * Returns the complete team membership record for a single team membership.
     * @returns any Successfully retrieved the requested team membership.
     * @throws ApiError
     */
    getTeamMembership({ teamMembershipGid, optPretty, optFields, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/team_memberships/{team_membership_gid}',
            path: {
                'team_membership_gid': teamMembershipGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Get team memberships
     * Returns compact team membership records.
     * @returns any Successfully retrieved the requested team memberships.
     * @throws ApiError
     */
    getTeamMemberships({ optPretty, optFields, limit, offset, team, user, workspace, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/team_memberships',
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
                'limit': limit,
                'offset': offset,
                'team': team,
                'user': user,
                'workspace': workspace,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Get memberships from a team
     * Returns the compact team memberships for the team.
     * @returns any Successfully retrieved the requested team's memberships.
     * @throws ApiError
     */
    getTeamMembershipsForTeam({ teamGid, optPretty, optFields, limit, offset, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/teams/{team_gid}/team_memberships',
            path: {
                'team_gid': teamGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
                'limit': limit,
                'offset': offset,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Get memberships from a user
     * Returns the compact team membership records for the user.
     * @returns any Successfully retrieved the requested users's memberships.
     * @throws ApiError
     */
    getTeamMembershipsForUser({ userGid, workspace, optPretty, optFields, limit, offset, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/users/{user_gid}/team_memberships',
            path: {
                'user_gid': userGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
                'limit': limit,
                'offset': offset,
                'workspace': workspace,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
}
exports.TeamMembershipsService = TeamMembershipsService;
