import type { TeamAddUserRequest } from '../models/TeamAddUserRequest';
import type { TeamCompact } from '../models/TeamCompact';
import type { TeamMembershipCompact } from '../models/TeamMembershipCompact';
import type { TeamRemoveUserRequest } from '../models/TeamRemoveUserRequest';
import type { TeamRequest } from '../models/TeamRequest';
import type { TeamResponse } from '../models/TeamResponse';
import type { CancelablePromise } from '../core/CancelablePromise';
import type { BaseHttpRequest } from '../core/BaseHttpRequest';
export declare class TeamsService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Create a team
     * Creates a team within the current workspace.
     * @returns any Successfully created a new team.
     * @throws ApiError
     */
    createTeam({ requestBody, optPretty, optFields, limit, offset, }: {
        /**
         * The team to create.
         */
        requestBody: {
            data?: TeamRequest;
        };
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
        /**
         * Results per page.
         * The number of objects to return per page. The value must be between 1 and 100.
         */
        limit?: number;
        /**
         * Offset token.
         * An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results.
         * 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
         */
        offset?: string;
    }): CancelablePromise<{
        data?: TeamResponse;
    }>;
    /**
     * Update a team
     * Updates a team within the current workspace.
     * @returns any Successfully updated the team.
     * @throws ApiError
     */
    updateTeam({ requestBody, optPretty, optFields, limit, offset, }: {
        /**
         * The team to update.
         */
        requestBody: {
            data?: TeamRequest;
        };
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
        /**
         * Results per page.
         * The number of objects to return per page. The value must be between 1 and 100.
         */
        limit?: number;
        /**
         * Offset token.
         * An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results.
         * 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
         */
        offset?: string;
    }): CancelablePromise<{
        data?: TeamResponse;
    }>;
    /**
     * Get a team
     * Returns the full record for a single team.
     * @returns any Successfully retrieved the record for a single team.
     * @throws ApiError
     */
    getTeam({ teamGid, optPretty, optFields, limit, offset, }: {
        /**
         * Globally unique identifier for the team.
         */
        teamGid: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
        /**
         * Results per page.
         * The number of objects to return per page. The value must be between 1 and 100.
         */
        limit?: number;
        /**
         * Offset token.
         * An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results.
         * 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
         */
        offset?: string;
    }): CancelablePromise<{
        data?: TeamResponse;
    }>;
    /**
     * Get teams in a workspace
     * Returns the compact records for all teams in the workspace visible to the authorized user.
     * @returns any Returns the team records for all teams in the organization or workspace accessible to the authenticated user.
     * @throws ApiError
     */
    getTeamsForWorkspace({ workspaceGid, optPretty, optFields, limit, offset, }: {
        /**
         * Globally unique identifier for the workspace or organization.
         */
        workspaceGid: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
        /**
         * Results per page.
         * The number of objects to return per page. The value must be between 1 and 100.
         */
        limit?: number;
        /**
         * Offset token.
         * An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results.
         * 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
         */
        offset?: string;
    }): CancelablePromise<{
        data?: Array<TeamCompact>;
    }>;
    /**
     * Get teams for a user
     * Returns the compact records for all teams to which the given user is assigned.
     * @returns any Returns the team records for all teams in the organization or workspace to which the given user is assigned.
     * @throws ApiError
     */
    getTeamsForUser({ userGid, organization, optPretty, optFields, limit, offset, }: {
        /**
         * A string identifying a user. This can either be the string "me", an email, or the gid of a user.
         */
        userGid: string;
        /**
         * The workspace or organization to filter teams on.
         */
        organization: string;
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
        /**
         * Results per page.
         * The number of objects to return per page. The value must be between 1 and 100.
         */
        limit?: number;
        /**
         * Offset token.
         * An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results.
         * 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
         */
        offset?: string;
    }): CancelablePromise<{
        data?: Array<TeamCompact>;
    }>;
    /**
     * Add a user to a team
     * The user making this call must be a member of the team in order to add others. The user being added must exist in the same organization as the team.
     *
     * Returns the complete team membership record for the newly added user.
     * @returns any Successfully added user to the team.
     * @throws ApiError
     */
    addUserForTeam({ teamGid, requestBody, optPretty, optFields, }: {
        /**
         * Globally unique identifier for the team.
         */
        teamGid: string;
        /**
         * The user to add to the team.
         */
        requestBody: {
            data?: TeamAddUserRequest;
        };
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<{
        data?: TeamMembershipCompact;
    }>;
    /**
     * Remove a user from a team
     * The user making this call must be a member of the team in order to remove themselves or others.
     * @returns void
     * @throws ApiError
     */
    removeUserForTeam({ teamGid, requestBody, optPretty, optFields, }: {
        /**
         * Globally unique identifier for the team.
         */
        teamGid: string;
        /**
         * The user to remove from the team.
         */
        requestBody: {
            data?: TeamRemoveUserRequest;
        };
        /**
         * Provides “pretty” output.
         * Provides the response in a “pretty” format. In the case of JSON this means doing proper line breaking and indentation to make it readable. This will take extra time and increase the response size so it is advisable only to use this during debugging.
         */
        optPretty?: boolean;
        /**
         * Defines fields to return.
         * Some requests return *compact* representations of objects in order to conserve resources and complete the request more efficiently. Other times requests return more information than you may need. This option allows you to list the exact set of fields that the API should be sure to return for the objects. The field names should be provided as paths, described below.
         * The id of included objects will always be returned, regardless of the field options.
         */
        optFields?: Array<string>;
    }): CancelablePromise<void>;
}
