"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TimePeriodsService = void 0;
class TimePeriodsService {
    constructor(httpRequest) {
        this.httpRequest = httpRequest;
    }
    /**
     * Get a time period
     * Returns the full record for a single time period.
     * @returns any Successfully retrieved the record for a single time period.
     * @throws ApiError
     */
    getTimePeriod({ timePeriodGid, optPretty, optFields, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/time_periods/{time_period_gid}',
            path: {
                'time_period_gid': timePeriodGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Get time periods
     * Returns compact time period records.
     * @returns any Successfully retrieved the requested time periods.
     * @throws ApiError
     */
    getTimePeriods({ workspace, optPretty, optFields, limit, offset, startOn, endOn, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/time_periods',
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
                'limit': limit,
                'offset': offset,
                'start_on': startOn,
                'end_on': endOn,
                'workspace': workspace,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
}
exports.TimePeriodsService = TimePeriodsService;
