"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WorkspaceMembershipsService = void 0;
class WorkspaceMembershipsService {
    constructor(httpRequest) {
        this.httpRequest = httpRequest;
    }
    /**
     * Get a workspace membership
     * Returns the complete workspace record for a single workspace membership.
     * @returns any Successfully retrieved the requested workspace membership.
     * @throws ApiError
     */
    getWorkspaceMembership({ workspaceMembershipGid, optPretty, optFields, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/workspace_memberships/{workspace_membership_gid}',
            path: {
                'workspace_membership_gid': workspaceMembershipGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Get workspace memberships for a user
     * Returns the compact workspace membership records for the user.
     * @returns any Successfully retrieved the requested user's workspace memberships.
     * @throws ApiError
     */
    getWorkspaceMembershipsForUser({ userGid, optPretty, optFields, limit, offset, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/users/{user_gid}/workspace_memberships',
            path: {
                'user_gid': userGid,
            },
            query: {
                'opt_pretty': optPretty,
                'opt_fields': optFields,
                'limit': limit,
                'offset': offset,
            },
            errors: {
                400: `This usually occurs because of a missing or malformed parameter. Check the documentation and the syntax of your request and try again.`,
                401: `A valid authentication token was not provided with the request, so the API could not associate a user with the request.`,
                403: `The authentication and request syntax was valid but the server is refusing to complete the request. This can happen if you try to read or write to objects or properties that the user does not have access to.`,
                404: `Either the request method and path supplied do not specify a known action in the API, or the object specified by the request does not exist.`,
                500: `There was a problem on Asana’s end. In the event of a server error the response body should contain an error phrase. These phrases can be used by Asana support to quickly look up the incident that caused the server error. Some errors are due to server load, and will not supply an error phrase.`,
            },
        });
    }
    /**
     * Get the workspace memberships for a workspace
     * Returns the compact workspace membership records for the workspace.
     * @returns any Successfully retrieved the requested workspace's memberships.
     * @throws ApiError
     */
    getWorkspaceMembershipsForWorkspace({ workspaceGid, user, optPretty, optFields, limit, offset, }) {
        return this.httpRequest.request({
            method: 'GET',
            url: '/workspaces/{workspace_gid}/workspace_memberships',
            path: {
                'workspace_gid': workspaceGid,
            },
            query: {
                'user': user,
                'opt_pretty': optPretty,
                'opt_fields': optFields,
                'limit': limit,
                'offset': offset,
            },
        });
    }
}
exports.WorkspaceMembershipsService = WorkspaceMembershipsService;
